@@ -1,3 +1,3 @@
 "extract" <-
 function (e, n, ...)
-	UseMethod("extract", e, n, ...)
+	UseMethod("extract")
